Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/prusa3d/PrusaSlicer.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'xs/src/slic3r/AppController.hpp')
-rw-r--r--xs/src/slic3r/AppController.hpp52
1 files changed, 15 insertions, 37 deletions
diff --git a/xs/src/slic3r/AppController.hpp b/xs/src/slic3r/AppController.hpp
index e9252b50c..3ef47ffdc 100644
--- a/xs/src/slic3r/AppController.hpp
+++ b/xs/src/slic3r/AppController.hpp
@@ -7,7 +7,7 @@
#include <atomic>
#include <iostream>
-#include "IProgressIndicator.hpp"
+#include "ProgressIndicator.hpp"
namespace Slic3r {
@@ -15,7 +15,8 @@ class Model;
class Print;
class PrintObject;
class PrintConfig;
-
+class ProgressStatusBar;
+class DynamicPrintConfig;
/**
* @brief A boilerplate class for creating application logic. It should provide
@@ -33,7 +34,7 @@ class AppControllerBoilerplate {
public:
/// A Progress indicator object smart pointer
- using ProgresIndicatorPtr = std::shared_ptr<IProgressIndicator>;
+ using ProgresIndicatorPtr = std::shared_ptr<ProgressIndicator>;
private:
class PriData; // Some structure to store progress indication data
@@ -46,7 +47,7 @@ public:
AppControllerBoilerplate();
~AppControllerBoilerplate();
- using Path = string;
+ using Path = std::string;
using PathList = std::vector<Path>;
/// Common runtime issue types
@@ -67,20 +68,20 @@ public:
* @return Returns a list of paths choosed by the user.
*/
PathList query_destination_paths(
- const string& title,
+ const std::string& title,
const std::string& extensions) const;
/**
* @brief Same as query_destination_paths but works for directories only.
*/
PathList query_destination_dirs(
- const string& title) const;
+ const std::string& title) const;
/**
* @brief Same as query_destination_paths but returns only one path.
*/
Path query_destination_path(
- const string& title,
+ const std::string& title,
const std::string& extensions,
const std::string& hint = "") const;
@@ -95,11 +96,11 @@ public:
* title.
*/
bool report_issue(IssueType issuetype,
- const string& description,
- const string& brief);
+ const std::string& description,
+ const std::string& brief);
bool report_issue(IssueType issuetype,
- const string& description);
+ const std::string& description);
/**
* @brief Return the global progress indicator for the current controller.
@@ -150,12 +151,12 @@ protected:
*/
ProgresIndicatorPtr create_progress_indicator(
unsigned statenum,
- const string& title,
- const string& firstmsg) const;
+ const std::string& title,
+ const std::string& firstmsg) const;
ProgresIndicatorPtr create_progress_indicator(
unsigned statenum,
- const string& title) const;
+ const std::string& title) const;
// This is a global progress indicator placeholder. In the Slic3r UI it can
// contain the progress indicator on the statusbar.
@@ -167,24 +168,6 @@ protected:
*/
class PrintController: public AppControllerBoilerplate {
Print *print_ = nullptr;
-protected:
-
- void make_skirt();
- void make_brim();
- void make_wipe_tower();
-
- void make_perimeters(PrintObject *pobj);
- void infill(PrintObject *pobj);
- void gen_support_material(PrintObject *pobj);
-
- /**
- * @brief Slice one pront object.
- * @param pobj The print object.
- */
- void slice(PrintObject *pobj);
-
- void slice(ProgresIndicatorPtr pri);
-
public:
// Must be public for perl to use it
@@ -199,11 +182,6 @@ public:
return PrintController::Ptr( new PrintController(print) );
}
- /**
- * @brief Slice the loaded print scene.
- */
- void slice();
-
const PrintConfig& config() const;
};
@@ -248,7 +226,7 @@ public:
* In perl we have a progress indicating status bar on the bottom of the
* window which is defined and created in perl. We can pass the ID-s of the
* gauge and the statusbar id and make a wrapper implementation of the
* IProgressIndicator interface so we can use this GUI widget from C++.
*
* This function should be called from perl.
*
@@ -248,7 +226,7 @@ public:
* window which is defined and created in perl. We can pass the ID-s of the
* gauge and the statusbar id and make a wrapper implementation of the
- * IProgressIndicator interface so we can use this GUI widget from C++.
+ * ProgressIndicator interface so we can use this GUI widget from C++.
*
* This function should be called from perl.